import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
	property string name: "companyStockQuotesListPage"
	property alias timerRef: timer
	Component.onCompleted: {
		loadingScreen.visible = true;
		loadingScreen.running = true;
		refreshButton.enabled = false;
		var msg = {'action': 'updateStockQuotesList', 'model': companyStocksQuotesListModel};
		refreshData.sendMessage(msg);
	}
	tools: ToolBarLayout {
		id: toolbar
		visible: true
		ToolIcon {
			id: refreshButton
			iconId: "toolbar-refresh"
			anchors.left: (parent === undefined) ? undefined : parent.left
			onClicked: {
				companyStocksQuotesList.visible = false;
				loadingScreen.visible = true;
				loadingScreen.running = true;
				enabled = false;
				var msg = {'action': 'updateStockQuotesList', 'model': companyStocksQuotesListModel};
				refreshData.sendMessage(msg);
			}
		}
		Text {
			id: marketStatus
			horizontalAlignment: Text.AlignHCenter
			anchors.horizontalCenter: parent.horizontalCenter
			font.bold: true
			font.pointSize: 13
		}
		ToolIcon {
			iconId: "toolbar-settings"
			anchors.right: (parent === undefined) ? undefined : parent.right
			onClicked: pageStack.push(Qt.createComponent("Settings.qml"),{'settingsData':{'running':timer.running,'interval':timer.interval}})
		}
	}

	QueryDialog {
		id: alertMessage
		acceptButtonText: "Ok"
	}

	Rectangle {
		id: header
		anchors.top: parent.top
		anchors.left: parent.left
		width: parent.width
		height: parent.height/10
		color: "#6eb500"
		Text {
			id: portfolioHeader
			anchors.left: parent.left
			anchors.leftMargin: 6
			anchors.verticalCenter: parent.verticalCenter
			font.pointSize: 25
			color: "white"
			wrapMode: Text.WrapAnywhere
			text: qsTr("Portfolios")
		}
	}
	BusyIndicator {
		id: loadingScreen
		anchors.centerIn: parent
		platformStyle: BusyIndicatorStyle {
			size: "large"
		}
	}
	ListView {
		id: companyStocksQuotesList
		anchors.fill: parent
		anchors.topMargin: header.height
		clip: true
		property string defaultColor
		model: ListModel {
			id: companyStocksQuotesListModel
		}
		WorkerScript {
			id: refreshData
			property string stockDataSerialized
			source: "dataloader.js"
			onMessage: {
				loadingScreen.running = false;
				loadingScreen.visible = false;
				refreshButton.enabled = true;
				if (messageObject.reply.error) {
					alertMessage.titleText = messageObject.reply.error;
					alertMessage.open();
				} else {
					stockDataSerialized = JSON.stringify(messageObject.reply);
					marketStatus.color = (messageObject.reply.marketStatus == "Open") ? "green" : "red";
					marketStatus.text = "Market Status: " + messageObject.reply.marketStatus + "\n" + Date().toString();
				}
				if (!companyStocksQuotesList.visible) {
					companyStocksQuotesList.visible = true;
				}
			}
		}

		Timer {
			id: timer
			interval: 10000; repeat: true
			triggeredOnStart: true
			onTriggered: {
				refreshButton.enabled = false;
				var msg = {'action': 'updateStockQuotesList', 'model': companyStocksQuotesListModel};
				refreshData.sendMessage(msg);
			}
			onRunningChanged: console.log("running is",running?" on":" off")
			onIntervalChanged: console.log("interval changed to ", interval)
		}

		delegate: Rectangle {
			width: parent.width
			height: 88
			color: mouseArea.pressed ? "lightgrey" : companyStocksQuotesList.defaultColor
			Component.onCompleted: {
				companyStocksQuotesList.defaultColor = color;
			}
			Label {
				text: companySymbol
				font.bold: true
				font.pointSize: 15
				anchors.left: parent.left
				anchors.verticalCenter: parent.verticalCenter
			}
			Label {
				text: stockQuoteChange + " (" + stockQuotePercentChange + "%)"
				font.bold: true
				font.pointSize: 15
				color: changeEffect
				anchors.right: parent.right
				anchors.verticalCenter: parent.verticalCenter
			}
			MouseArea {
				id : mouseArea
				anchors.fill: parent
				onClicked: {
					var temp = JSON.parse(refreshData.stockDataSerialized);
					pageStack.push(Qt.createComponent("CompanyStockQuoteDetailsPage.qml"), {'stockQuoteDetails': temp.data[sectionName][companySymbol]});
				}
			}
		}
		section.property: "sectionName"
		section.criteria: ViewSection.FullString
		section.delegate: Rectangle {
			width: parent.width
			height: 40
			color: companyStocksQuotesList.defaultColor
			Text {
				id: sectionLabel
				anchors.right: parent.right
				anchors.bottom: parent.bottom
				anchors.rightMargin: 10
				anchors.bottomMargin: 4
				text: section
				font.bold: true
				font.pointSize: 20
				color: theme.inverted ? "#4D4D4D" : "#3C3C3C"
			}
			Image {
				anchors.right: sectionLabel.left
				anchors.left: parent.left
				anchors.verticalCenter: sectionLabel.verticalCenter
				anchors.rightMargin: 26
				source: "image://theme/meegotouch-groupheader" + (theme.inverted ? "-inverted" : "") + "-background"
			}
		}
	}

	ScrollDecorator {
		flickableItem: companyStocksQuotesList
	}
	SectionScroller {
		listView: companyStocksQuotesList
	}
}
