// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Page {
	property variant settingsData
	Component.onCompleted: {
		for(var itemIndex=0; itemIndex < frequencySelectionDialog.model.count;itemIndex++) {
			if(frequencySelectionDialog.model.get(itemIndex).interval == settingsData['interval']) {
				frequencySelectionDialog.selectedIndex = itemIndex;
				break;
			}
		}
	}
	tools: ToolBarLayout {
		visible: true
		ToolIcon {
			iconId: "toolbar-back"
			anchors.left: (parent === undefined) ? undefined : parent.left
			onClicked: pageStack.pop()
		}
		ToolIcon {
			iconSource: "base_meegotouch_icons_icon-m-startup-help.svg"
			anchors.right: (parent === undefined) ? undefined : parent.right
			onClicked: aboutDialog.open()
		}
	}
	QueryDialog {
		id: aboutDialog
		icon: "testLogo.png"
		titleText: "Abu Dhabi Securities Exchange"
        message: "Market Watch (Version 1.1.0)"
		acceptButtonText: "Ok"
	}

	Rectangle {
		id: header
		anchors.top: parent.top
		anchors.left: parent.left
		width: parent.width
		height: parent.height/10
		color: "#515151"
		Text {
			id: settingsHeader
			anchors.left: parent.left
			anchors.leftMargin: 6
			anchors.verticalCenter: parent.verticalCenter
			font.pointSize: 25
			color: "white"
			wrapMode: Text.WrapAnywhere
			text: qsTr("Settings")
		}
	}
	SelectionDialog {
		id : frequencySelectionDialog
		model: ListModel {
			ListElement { name : "10 seconds"; interval : 10000 }
			ListElement { name : "30 seconds"; interval : 30000 }
			ListElement { name : "1 minute"; interval : 60000 }
			ListElement { name : "5 minutes"; interval : 300000 }
			ListElement { name : "10 minutes"; interval : 600000 }
			ListElement { name : "30 minutes"; interval : 1800000 }
			ListElement { name : "1 hour"; interval : 6000000 }
		}
		onSelectedIndexChanged: pageStack.find(function(page) { return page.name == "companyStockQuotesListPage"; }).timerRef.interval = frequencySelectionDialog.model.get(frequencySelectionDialog.selectedIndex).interval
	}
	ListView {
		id : settings
		anchors.top: header.bottom
		anchors.bottom: parent.bottom
		width: parent.width
		anchors.left: parent.left
		clip: true
		model : VisualItemModel {
			Rectangle {
				id: settingsElement1
				width: settings.width
				height: 80
				Label {
					text: "Auto-update"
					font.bold: true
					font.pointSize: 15
					anchors.verticalCenter: parent.verticalCenter
				}
				Switch {
					id : autoUpdateSwitch
					anchors.right: parent.right
					checked: settingsData['running']
					anchors.verticalCenter: parent.verticalCenter
					onCheckedChanged: (checked) ? pageStack.find(function(page) { return page.name == "companyStockQuotesListPage"; }).timerRef.restart() : pageStack.find(function(page) { return page.name == "companyStockQuotesListPage"; }).timerRef.stop()
				}
			}
			Rectangle {
				id: settingsElement2
				width: settings.width
				height: 80
				enabled: autoUpdateSwitch.checked
				Column {
					anchors.verticalCenter: parent.verticalCenter
					Label {
						text: "Auto-update Frequency"
						font.bold: true
						font.pointSize: 15
					}
					Label {
						text: frequencySelectionDialog.model.get(frequencySelectionDialog.selectedIndex).name
						font.pointSize: 10
					}
				}
				Image {
					anchors.right: parent.right
					anchors.verticalCenter: parent.verticalCenter
					source: "image://theme/meegotouch-combobox-indicator" +
									(theme.inverted ? "-inverted" : "") +
									(settingsElement2.enabled ? "" : "-disabled") +
									(mouseArea.pressed ? "-pressed" : "")
				}

				MouseArea {
					id: mouseArea
					anchors.fill: parent
					onClicked: frequencySelectionDialog.open()
				}
			}
		}
	}
}
